@@ -8,6 +8,17 @@
 # Last changed:  2011-12-11
 #*/
 
+#define _INTEGER64_C_SRC
+
+
+
+
+/*****************************************************************************/
+/**                                                                         **/
+/**                            MODULES USED                                 **/
+/**                                                                         **/
+/*****************************************************************************/
+
 #include "ctype.h"
 #include "stdio.h"
 
@@ -18,8 +29,55 @@
 
 # include "integer64.h"
 
+
+/*****************************************************************************/
+/**                                                                         **/
+/**                      DEFINITIONS AND MACROS                             **/
+/**                                                                         **/
+/*****************************************************************************/
+
 #define mod_iterate(n1,n2,i1,i2) for (i=i1=i2=0; i<n; i1 = (++i1 == n1) ? 0 : i1, i2 = (++i2 == n2) ? 0 : i2,++i)
-	
+
+/*****************************************************************************/
+/**                                                                         **/
+/**                      TYPEDEFS AND STRUCTURES                            **/
+/**                                                                         **/
+/*****************************************************************************/
+
+/*****************************************************************************/
+/**                                                                         **/
+/**                   PROTOTYPYPES OF LOCAL FUNCTIONS                       **/
+/**                                                                         **/
+/*****************************************************************************/
+
+// static
+
+
+/*****************************************************************************/
+/**                                                                         **/
+/**                        EXPORTED VARIABLES                               **/
+/**                                                                         **/
+/*****************************************************************************/
+
+// no static no extern
+
+
+/*****************************************************************************/
+/**                                                                         **/
+/**                          GLOBAL VARIABLES                               **/
+/**                                                                         **/
+/*****************************************************************************/
+
+// static
+
+/*****************************************************************************/
+/**                                                                         **/
+/**                        EXPORTED FUNCTIONS                               **/
+/**                                                                         **/
+/*****************************************************************************/
+
+// no extern
+
 SEXP as_integer64_double(SEXP x_, SEXP ret_){
   long long i, n = LENGTH(x_);
   long long * ret = (long long *) REAL(ret_);
@@ -537,6 +595,34 @@ SEXP sum_integer64(SEXP e1_, SEXP na_rm_, SEXP ret_){
   return ret_;
 }
 
+SEXP mean_integer64(SEXP e1_, SEXP na_rm_, SEXP ret_){
+	long long i, n = LENGTH(e1_);
+	long long * e1 = (long long *) REAL(e1_);
+	long long * ret = (long long *) REAL(ret_);
+	long double longret = 0;
+	if (asLogical(na_rm_)){
+		long long nvalid = 0;
+		for(i=0; i<n; i++){
+			if (e1[i]!=NA_INTEGER64){
+				longret += e1[i];
+				nvalid++;
+			}
+		}
+		ret[0] = longret / nvalid;
+	}else{
+		for(i=0; i<n; i++){
+			if (e1[i]==NA_INTEGER64){
+				ret[0] = NA_INTEGER64;
+				return ret_;
+			}else{
+				longret += e1[i];			
+			}
+		}
+		ret[0] = longret / n;
+	}
+  return ret_;
+}
+
 SEXP prod_integer64(SEXP e1_, SEXP na_rm_, SEXP ret_){
   long long i, n = LENGTH(e1_);
   long long * e1 = (long long *) REAL(e1_);
@@ -844,3 +930,23 @@ SEXP GE_integer64(SEXP e1_, SEXP e2_, SEXP ret_){
   return ret_;
 }
 
+
+/*****************************************************************************/
+/**                                                                         **/
+/**                           LOCAL FUNCTIONS                               **/
+/**                                                                         **/
+/*****************************************************************************/
+
+// static
+
+
+/*****************************************************************************/
+/**                                                                         **/
+/**                                EOF                                      **/
+/**                                                                         **/
+/*****************************************************************************/
+
+
+
+	
+
